@@ -50,7 +50,7 @@ def process_file(file_name):
         content = content.replace("(" + md_path + ")", normalize_path(path))
 
     for url in urls:
-        path = url[len(GITHUB_URL):]
+        path = url[len(GITHUB_URL) :]  # noqa: E203
         paths.add(path)
         content = content.replace(
             url, normalize_path(os.path.relpath(path, directory))
@@ -83,9 +83,9 @@ def main(*args, **kwargs):
         process_file(file_)
 
     readme_file = "./docs/README.md"
-    with open(readme_file, 'r', encoding='utf-8') as f:
+    with open(readme_file, "r", encoding="utf-8") as f:
         all_code = f.read()
-    code_lines = all_code.split('\n')
+    code_lines = all_code.split("\n")
 
     changed = False
     seleniumbase_lines = []
@@ -99,24 +99,27 @@ def main(*args, **kwargs):
                 r'<p align="center"><div align="center">'
                 r'<a href="https://github.com/seleniumbase/SeleniumBase">'
                 r'<img src="https://img.shields.io/badge/'
-                r'✅%20💛%20View%20Code-on%20GitHub%20🌎%20🚀'
+                r"✅%20💛%20View%20Code-on%20GitHub%20🌎%20🚀"
                 r'-02A79E.svg" alt="SeleniumBase on GitHub" />'
-                r'</a></div></p>')
+                r"</a></div></p>"
+            )
         if "<!-- SeleniumBase Header1 -->" in line:
             changed = True
             line = (
                 '<section align="center"><div align="center">'
-                '<h2>✅ Reliable Browser Testing</h2>'
-                '</div></section>')
+                "<h2>✅ Reliable Browser Testing</h2>"
+                "</div></section>"
+            )
         if "<!-- SeleniumBase Docs -->" in line:
             changed = True
             line = (
                 '<h2><img src="https://seleniumbase.io/img/sb_icon.png" '
                 'title="SeleniumBase" width="20" /> SeleniumBase Docs '
                 '<img src="https://seleniumbase.io/img/sb_icon.png" '
-                'title="SeleniumBase" width="20" /></h2>')
+                'title="SeleniumBase" width="20" /></h2>'
+            )
         seleniumbase_lines.append(line)
     if changed:
-        out_file = codecs.open(readme_file, "w+", encoding='utf-8')
+        out_file = codecs.open(readme_file, "w+", encoding="utf-8")
         out_file.writelines("\r\n".join(seleniumbase_lines))
         out_file.close()
