@@ -1,23 +1,29 @@
-'''
+"""
 You can use this as a boilerplate for your test framework.
 Define your customized library methods in a master class like this.
 Then have all your test classes inherit it.
 BaseTestCase will inherit SeleniumBase methods from BaseCase.
 With Python 3, simplify "super(...)" to super().setUp() and super().tearDown()
-'''
+"""
 
 from seleniumbase import BaseCase
 
 
 class BaseTestCase(BaseCase):
-
     def setUp(self):
         super(BaseTestCase, self).setUp()
-        # <<< Add custom setUp code for tests AFTER the super().setUp() >>>
+        # <<< Run custom setUp() code for tests AFTER the super().setUp() >>>
 
     def tearDown(self):
         self.save_teardown_screenshot()
-        # <<< Add custom tearDown code BEFORE the super().tearDown() >>>
+        if self.has_exception():
+            # <<< Run custom code if the test failed. >>>
+            pass
+        else:
+            # <<< Run custom code if the test passed. >>>
+            pass
+        # (Wrap unreliable tearDown() code in a try/except block.)
+        # <<< Run custom tearDown() code BEFORE the super().tearDown() >>>
         super(BaseTestCase, self).tearDown()
 
     def login(self):
@@ -31,7 +37,7 @@ class BaseTestCase(BaseCase):
         pass
 
 
-'''
+"""
 # Now you can do something like this in your test files:
 
 from base_test_case import BaseTestCase
@@ -41,4 +47,7 @@ class MyTests(BaseTestCase):
     def test_example(self):
         self.login()
         self.example_method()
-'''
+        self.type("input", "Name")
+        self.click("form button")
+        ...
+"""
