@@ -2,7 +2,6 @@ from seleniumbase import BaseCase
 
 
 class GitHubTests(BaseCase):
-
     def test_github(self):
         # Selenium can trigger GitHub's anti-automation system:
         # "You have triggered an abuse detection mechanism."
@@ -12,14 +11,14 @@ class GitHubTests(BaseCase):
         # 2. The browser's User Agent is modified to avoid Selenium-detection
         #    when running in headless mode on Chrome or Edge (Chromium).
         if self.headless and (
-                self.browser == "chrome" or self.browser == "edge"):
-            self.driver.quit()
+            self.browser == "chrome" or self.browser == "edge"
+        ):
             self.get_new_driver(
-                agent="""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) """
-                      """AppleWebKit/537.36 (KHTML, like Gecko) """
-                      """Chrome/75.0.3770.100 Safari/537.36""")
-        self.open("https://github.com/")
-        self.type("input.header-search-input", "SeleniumBase\n")
+                agent="""Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) """
+                """AppleWebKit/537.36 (KHTML, like Gecko) """
+                """Chrome/90.0.4430.85 Safari/537.36"""
+            )
+        self.open("https://github.com/search?q=SeleniumBase")
         self.slow_click('a[href="/seleniumbase/SeleniumBase"]')
         self.click_if_visible('[data-action="click:signup-prompt#dismiss"]')
         self.assert_element("div.repository-content")
