@@ -1,10 +1,9 @@
 from seleniumbase import BaseCase
 
 
-class MyTestClass(BaseCase):
-
+class UserAgentTests(BaseCase):
     def test_user_agent(self):
-        self.open('http://whatsmyuseragent.org/')
+        self.open("http://whatsmyuseragent.org/")
         user_agent = self.get_text(".user-agent p")
         print("\n\nUser-Agent:\n%s\n" % user_agent)
         print(self.get_text(".ip-address p"))
