@@ -2,16 +2,17 @@
 from seleniumbase import BaseCase
 
 
-class ChinesePdfTestClass(BaseCase):
-
+class ChinesePdfTests(BaseCase):
     def test_chinese_pdf(self):
 
-        pdf = ('https://github.com/seleniumbase/SeleniumBase/'
-               'files/3895614/unittest.pdf')
+        pdf = (
+            "https://github.com/seleniumbase/SeleniumBase/"
+            "files/3895614/unittest.pdf"
+        )
 
         # Get and print PDF text
         pdf_text = self.get_pdf_text(pdf, page=2)
-        print("\n" + pdf_text)
+        self._print("\n" + pdf_text)
 
         # Assert PDF contains the expected text on Page 2
         self.assert_pdf_text(pdf, "个测试类", page=2)
