@@ -1,10 +1,12 @@
 from seleniumbase import BaseCase
 
 
-class MyTestClass(BaseCase):
-
+class DemoSiteTests(BaseCase):
     def test_demo_site(self):
-        self.open("https://seleniumbase.io/demo_page.html")
+        self.open("https://seleniumbase.io/demo_page")
+
+        # Assert the title of the current web page
+        self.assert_title("Web Testing Page")
 
         # Assert that the element is visible on the page
         self.assert_element("tbody#tbodyId")
@@ -12,10 +14,10 @@ class MyTestClass(BaseCase):
         # Assert that the text appears within a given element
         self.assert_text("Demo Page", "h1")
 
-        # Update the text of various text fields on the page
-        self.update_text("#myTextInput", "This is Automated")
-        self.update_text("textarea.area1", "Testing Time!\n")
-        self.update_text('[name="preText2"]', "Typing Text!")
+        # Type/update text in text fields on the page
+        self.type("#myTextInput", "This is Automated")
+        self.type("textarea.area1", "Testing Time!\n")
+        self.type('[name="preText2"]', "Typing Text!")
 
         # Verify that a hover dropdown link changes page text
         self.assert_text("Automation Practice", "h3")
@@ -30,7 +32,7 @@ class MyTestClass(BaseCase):
         # Assert that the given SVG is visible on the page
         self.assert_element('svg[name="svgName"]')
 
-        # Verify that a slider control updates a progrss bar
+        # Verify that a slider control updates a progress bar
         self.assert_element('progress[value="50"]')
         self.press_right_arrow("#myslider", times=5)
         self.assert_element('progress[value="100"]')
@@ -80,9 +82,22 @@ class MyTestClass(BaseCase):
         self.assert_true(self.is_selected(".fBox"))
         self.switch_to_default_content()
 
-        # Assert link text - Use click_link_text() to click
+        # Assert link text
         self.assert_link_text("seleniumbase.com")
         self.assert_link_text("SeleniumBase on GitHub")
+        self.assert_link_text("seleniumbase.io")
 
-        # Assert the title of the current web page
-        self.assert_title("Web Testing Page")
+        # Click link text
+        self.click_link("SeleniumBase Demo Page")
+
+        # Assert exact text
+        self.assert_exact_text("Demo Page", "h1")
+
+        # Highlight a page element (Also asserts visibility)
+        self.highlight("h2")
+
+        # Assert no broken links (Can be slow if many links)
+        # self.assert_no_404_errors()
+
+        # Assert no JavaScript errors (Can also detect 404s)
+        # self.assert_no_js_errors()
