@@ -1,7 +1,6 @@
 from seleniumbase import BaseCase
 
 
-class MyTestClass(BaseCase):
-
+class NullTests(BaseCase):
     def test_null(self):
         pass
