@@ -3,7 +3,6 @@ from seleniumbase.translate.dutch import Testgeval
 
 
 class MijnTestklasse(Testgeval):
-
     def test_voorbeeld_1(self):
         self.openen("https://nl.wikipedia.org/wiki/Hoofdpagina")
         self.controleren_element('a[title*="hoofdpagina gaan"]')
@@ -11,11 +10,11 @@ class MijnTestklasse(Testgeval):
         self.typ("#searchInput", "Stroopwafel")
         self.klik("#searchButton")
         self.controleren_tekst("Stroopwafel", "#firstHeading")
-        self.controleren_element('img[alt="Stroopwafels"]')
+        self.controleren_element('img[src*="Stroopwafels"]')
         self.typ("#searchInput", "Rijksmuseum Amsterdam")
         self.klik("#searchButton")
         self.controleren_tekst("Rijksmuseum", "#firstHeading")
-        self.controleren_element('img[alt="Het Rijksmuseum"]')
+        self.controleren_element('img[src*="Rijksmuseum"]')
         self.terug()
         self.controleren_ware("Stroopwafel" in self.huidige_url_ophalen())
         self.vooruit()
