@@ -1,10 +1,9 @@
 from seleniumbase import BaseCase
 
 
-class MyTestClass(BaseCase):
-
+class UserAgentTests(BaseCase):
     def test_user_agent(self):
-        self.open('https://www.whatsmyua.info/')
+        self.open("https://www.whatsmyua.info/")
         user_agent = self.get_text("#custom-ua-string")
         print("\n\nUser-Agent = %s\n" % user_agent)
         print("Displaying User-Agent Info:")
