@@ -2,10 +2,11 @@ from seleniumbase import BaseCase
 
 
 class MyTestClass(BaseCase):
-
-    def test_basic(self):
-        self.open("https://store.xkcd.com/search")
-        self.type('input[name="q"]', "xkcd book\n")
+    def test_basics(self):
+        url = "https://store.xkcd.com/collections/posters"
+        self.open(url)
+        self.type('input[name="q"]', "xkcd book")
+        self.click('input[value="Search"]')
         self.assert_text("xkcd: volume 0", "h3")
         self.open("https://xkcd.com/353/")
         self.assert_title("xkcd: Python")
@@ -13,5 +14,5 @@ class MyTestClass(BaseCase):
         self.click('a[rel="license"]')
         self.assert_text("free to copy and reuse")
         self.go_back()
-        self.click_link_text("About")
+        self.click_link("About")
         self.assert_exact_text("xkcd.com", "h2")
