@@ -17,19 +17,43 @@ Format: A CSS Selector that's ready for JavaScript's querySelectorAll()
 """
 
 AD_BLOCK_LIST = [
-    '[src*="/adservice."]',
-    '[src*="doubleclick.net"]',
-    '[src*="googletagservices.com"]',
-    '[src*="adsbygoogle.js"]',
+    '[aria-label="Ads"]',
+    '[src*="adservice."]',
+    '[src*="adclick"]',
+    '[src*="doubleclick"]',
+    '[src*="snigelweb.com"]',
+    '[src*="tagservices.com"]',
+    '[src*="adsby"]',
     '[src*="adroll.com"]',
-    '[src*="/pagead/"]',
+    '[src*="pagead"]',
+    '[src*="3lift"]',
+    '[src*="smartads."]',
+    '[src*="ad_nexus"]',
+    '[src*="/ads/"]',
+    '[src*="moatads.com"]',
+    '[src*="adsystem"]',
+    '[src*="connectad"]',
+    '[src*="/adservice."]',
+    '[src*="syndication.com"]',
+    '[src*="/ads."]',
+    '[src*="lijit"]',
+    '[src*="pagead"]',
+    '[src*="adnxs.com"]',
+    '[src*="onetag-sys.com"]',
+    '[src*="indexww.com"]',
+    '[src*="3lift.com"]',
+    '[src*="rubiconproject.com"]',
+    '[src*="brealtime.com"]',
+    '[src*="33across.com"]',
+    '[src*="adsrvr"]',
     '[type="data-doubleclick"]',
-    'iframe[data-google-container-id]',
-    'iframe[src*="doubleclick.net"]',
+    "iframe[data-google-container-id]",
+    'iframe[src*="doubleclick"]',
     'iframe[src*="/AdServer/"]',
     'iframe[src*="openx.net"]',
     'iframe[onload*="doWithAds"]',
-    'iframe[id*="google_ads_frame"]',
+    'iframe[id*="_ads_frame"]',
+    'iframe[style="height:0px;width:0px;display:none;"]',
     '[aria-label="Ad"]',
     '[class*="sponsored-content"]',
     '[class*="adsbygoogle"]',
@@ -40,15 +64,15 @@ AD_BLOCK_LIST = [
     '[data-type="ad"]',
     '[data-track-event-label*="-taboola-"]',
     '[data-ad-feedback-beacon*="AD_"]',
-    '[data-ad-feedback-beacon]',
+    "[data-ad-feedback-beacon]",
     '[data-dcm-click-tracker*="/adclick."]',
-    '[data-google-av-adk]',
-    '[data-google-query-id]',
-    '[data-ylk*="pkgt:sponsored_cluster"]',
-    '[data-google-av-cxn*="pagead2"]',
-    '[data-ad-client]',
-    '[data-ad-slot]',
-    '[href*="doubleclick.net/"]',
+    "[data-google-av-adk]",
+    "[data-google-query-id]",
+    '[data-ylk*="sponsored_cluster"]',
+    '[data-google-av-cxn*="pagead"]',
+    "[data-ad-client]",
+    "[data-ad-slot]",
+    '[href*="doubleclick"]',
     '[href*="amazon-adsystem"]',
     '[alt="Advertisement"]',
     '[id*="-ad-"]',
@@ -63,27 +87,24 @@ AD_BLOCK_LIST = [
     '[id^="google_ads_iframe"]',
     '[id="tryitLeaderboard"]',
     '[id="dianomiRightRail"]',
-    '[src*="smartads."]',
-    '[src*="ad_nexus"]',
-    '[src*="/ads/"]',
     '[allow*="advertising.com"]',
-    'ins.adsbygoogle',
-    'li.strm-ad-clusters',
-    'li.js-stream-ad',
-    'div.after_ad',
-    'div.ad-container',
-    'div.ad_module',
-    'div.ad-subnav-container',
-    'div.ad-wrapper',
-    'div.adroll-block',
-    'div.data-ad-container',
-    'div.GoogleActiveViewElement',
-    'div.l-ad',
-    'div.right-ad',
-    'div.wx-adWrapper',
-    'div.image > a > img[src*="HomepageAd-"]',
-    'img[src*="HomepageAd-"]',
-    'img.img_ad',
+    "ins.adsby",
+    "li.strm-ad-clusters",
+    "li.js-stream-ad",
+    "div.after_ad",
+    "div.ad-container",
+    "div.ad_module",
+    "div.ad-subnav-container",
+    "div.ad-wrapper",
+    "div.adroll-block",
+    "div.data-ad-container",
+    "div.GoogleActiveViewElement",
+    "div.l-ad",
+    "div.right-ad",
+    "div.wx-adWrapper",
+    'div.image > a > img[src*="HomepageAd"]',
+    'img[src*="HomepageAd"]',
+    "img.img_ad",
     'link[href*="/adservice."]',
-    'section.dianomi-ad'
+    "section.dianomi-ad",
 ]
