@@ -12,13 +12,13 @@ class ApplicationManager:
 
     @classmethod
     def generate_application_string(cls, test):
-        """ Generate an application string based on some of the given information
-            that can be pulled from the test object: app_env, start_time. """
+        """Generate an application string based on some of the given information
+        that can be pulled from the test object: app_env, start_time."""
 
-        app_env = 'test'
-        if hasattr(test, 'env'):
+        app_env = "test"
+        if hasattr(test, "env"):
             app_env = test.env
-        elif hasattr(test, 'environment'):
+        elif hasattr(test, "environment"):
             app_env = test.environment
 
         start_time = int(time.time() * 1000)
