@@ -23,20 +23,18 @@ import codecs
 import os
 import sys
 import time
+from selenium.common.exceptions import ElementNotInteractableException
+from selenium.common.exceptions import ElementNotVisibleException
+from selenium.common.exceptions import NoAlertPresentException
+from selenium.common.exceptions import NoSuchAttributeException
+from selenium.common.exceptions import NoSuchElementException
+from selenium.common.exceptions import NoSuchFrameException
+from selenium.common.exceptions import NoSuchWindowException
 from selenium.common.exceptions import StaleElementReferenceException
-from selenium.common import exceptions as selenium_exceptions
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.action_chains import ActionChains
-from selenium.webdriver.remote.errorhandler import ElementNotVisibleException
-from selenium.webdriver.remote.errorhandler import NoSuchElementException
-from selenium.webdriver.remote.errorhandler import NoAlertPresentException
-from selenium.webdriver.remote.errorhandler import NoSuchFrameException
-from selenium.webdriver.remote.errorhandler import NoSuchWindowException
 from seleniumbase.config import settings
-from seleniumbase.core import log_helper
-from seleniumbase.fixtures import page_utils
 from seleniumbase.fixtures import shared_utils as s_utils
-ENI_Exception = selenium_exceptions.ElementNotInteractableException
 
 
 def is_element_present(driver, selector, by=By.CSS_SELECTOR):
@@ -73,6 +71,23 @@ def is_element_visible(driver, selector, by=By.CSS_SELECTOR):
         return False
 
 
+def is_element_enabled(driver, selector, by=By.CSS_SELECTOR):
+    """
+    Returns whether the specified element selector is enabled on the page.
+    @Params
+    driver - the webdriver object (required)
+    selector - the locator for identifying the page element (required)
+    by - the type of selector being used (Default: By.CSS_SELECTOR)
+    @Returns
+    Boolean (is element enabled)
+    """
+    try:
+        element = driver.find_element(by=by, value=selector)
+        return element.is_enabled()
+    except Exception:
+        return False
+
+
 def is_text_visible(driver, text, selector, by=By.CSS_SELECTOR):
     """
     Returns whether the specified text is visible in the specified selector.
@@ -113,13 +128,18 @@ def hover_element(driver, element):
 
 
 def timeout_exception(exception, message):
-    exc, message = s_utils.format_exc(exception, message)
-    raise exc(message)
+    exception, message = s_utils.format_exc(exception, message)
+    raise exception(message)
 
 
-def hover_and_click(driver, hover_selector, click_selector,
-                    hover_by=By.CSS_SELECTOR, click_by=By.CSS_SELECTOR,
-                    timeout=settings.SMALL_TIMEOUT):
+def hover_and_click(
+    driver,
+    hover_selector,
+    click_selector,
+    hover_by=By.CSS_SELECTOR,
+    click_by=By.CSS_SELECTOR,
+    timeout=settings.SMALL_TIMEOUT,
+):
     """
     Fires the hover event for a specified element by a given selector, then
     clicks on another element specified. Useful for dropdown hover based menus.
@@ -149,15 +169,21 @@ def hover_and_click(driver, hover_selector, click_selector,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Element {%s} was not present after %s second%s!"
-        "" % (click_selector, timeout, plural))
+    message = "Element {%s} was not present after %s second%s!" % (
+        click_selector,
+        timeout,
+        plural,
+    )
     timeout_exception(NoSuchElementException, message)
 
 
-def hover_element_and_click(driver, element, click_selector,
-                            click_by=By.CSS_SELECTOR,
-                            timeout=settings.SMALL_TIMEOUT):
+def hover_element_and_click(
+    driver,
+    element,
+    click_selector,
+    click_by=By.CSS_SELECTOR,
+    timeout=settings.SMALL_TIMEOUT,
+):
     """
     Similar to hover_and_click(), but assumes top element is already found.
     """
@@ -178,15 +204,21 @@ def hover_element_and_click(driver, element, click_selector,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Element {%s} was not present after %s second%s!"
-        "" % (click_selector, timeout, plural))
+    message = "Element {%s} was not present after %s second%s!" % (
+        click_selector,
+        timeout,
+        plural,
+    )
     timeout_exception(NoSuchElementException, message)
 
 
-def hover_element_and_double_click(driver, element, click_selector,
-                                   click_by=By.CSS_SELECTOR,
-                                   timeout=settings.SMALL_TIMEOUT):
+def hover_element_and_double_click(
+    driver,
+    element,
+    click_selector,
+    click_by=By.CSS_SELECTOR,
+    timeout=settings.SMALL_TIMEOUT,
+):
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     hover = ActionChains(driver).move_to_element(element)
@@ -207,14 +239,17 @@ def hover_element_and_double_click(driver, element, click_selector,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Element {%s} was not present after %s second%s!"
-        "" % (click_selector, timeout, plural))
+    message = "Element {%s} was not present after %s second%s!" % (
+        click_selector,
+        timeout,
+        plural,
+    )
     timeout_exception(NoSuchElementException, message)
 
 
-def wait_for_element_present(driver, selector, by=By.CSS_SELECTOR,
-                             timeout=settings.LARGE_TIMEOUT):
+def wait_for_element_present(
+    driver, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector. Returns the
     element object if it exists in the HTML. (The element can be invisible.)
@@ -245,14 +280,17 @@ def wait_for_element_present(driver, selector, by=By.CSS_SELECTOR,
     if timeout == 1:
         plural = ""
     if not element:
-        message = (
-            "Element {%s} was not present after %s second%s!"
-            "" % (selector, timeout, plural))
+        message = "Element {%s} was not present after %s second%s!" % (
+            selector,
+            timeout,
+            plural,
+        )
         timeout_exception(NoSuchElementException, message)
 
 
-def wait_for_element_visible(driver, selector, by=By.CSS_SELECTOR,
-                             timeout=settings.LARGE_TIMEOUT):
+def wait_for_element_visible(
+    driver, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector. Returns the
     element object if the element is present and visible on the page.
@@ -293,24 +331,31 @@ def wait_for_element_visible(driver, selector, by=By.CSS_SELECTOR,
     if not element and by != By.LINK_TEXT:
         if not is_present:
             # The element does not exist in the HTML
-            message = (
-                "Element {%s} was not present after %s second%s!"
-                "" % (selector, timeout, plural))
+            message = "Element {%s} was not present after %s second%s!" % (
+                selector,
+                timeout,
+                plural,
+            )
             timeout_exception(NoSuchElementException, message)
         # The element exists in the HTML, but is not visible
-        message = (
-            "Element {%s} was not visible after %s second%s!"
-            "" % (selector, timeout, plural))
+        message = "Element {%s} was not visible after %s second%s!" % (
+            selector,
+            timeout,
+            plural,
+        )
         timeout_exception(ElementNotVisibleException, message)
     if not element and by == By.LINK_TEXT:
-        message = (
-            "Link text {%s} was not visible after %s second%s!"
-            "" % (selector, timeout, plural))
+        message = "Link text {%s} was not visible after %s second%s!" % (
+            selector,
+            timeout,
+            plural,
+        )
         timeout_exception(ElementNotVisibleException, message)
 
 
-def wait_for_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
-                          timeout=settings.LARGE_TIMEOUT):
+def wait_for_text_visible(
+    driver, text, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector. Returns the
     element object if the text is present in the element and visible
@@ -353,19 +398,23 @@ def wait_for_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     if not element:
         if not is_present:
             # The element does not exist in the HTML
-            message = (
-                "Element {%s} was not present after %s second%s!"
-                "" % (selector, timeout, plural))
+            message = "Element {%s} was not present after %s second%s!" % (
+                selector,
+                timeout,
+                plural,
+            )
             timeout_exception(NoSuchElementException, message)
         # The element exists in the HTML, but the text is not visible
         message = (
             "Expected text {%s} for {%s} was not visible after %s second%s!"
-            "" % (text, selector, timeout, plural))
+            % (text, selector, timeout, plural)
+        )
         timeout_exception(ElementNotVisibleException, message)
 
 
-def wait_for_exact_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
-                                timeout=settings.LARGE_TIMEOUT):
+def wait_for_exact_text_visible(
+    driver, text, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector. Returns the
     element object if the text matches exactly with the text in the element,
@@ -408,19 +457,109 @@ def wait_for_exact_text_visible(driver, text, selector, by=By.CSS_SELECTOR,
     if not element:
         if not is_present:
             # The element does not exist in the HTML
-            message = (
-                "Element {%s} was not present after %s second%s!"
-                "" % (selector, timeout, plural))
+            message = "Element {%s} was not present after %s second%s!" % (
+                selector,
+                timeout,
+                plural,
+            )
             timeout_exception(NoSuchElementException, message)
         # The element exists in the HTML, but the exact text is not visible
         message = (
             "Expected exact text {%s} for {%s} was not visible "
-            "after %s second%s!" % (text, selector, timeout, plural))
+            "after %s second%s!" % (text, selector, timeout, plural)
+        )
         timeout_exception(ElementNotVisibleException, message)
 
 
-def wait_for_element_absent(driver, selector, by=By.CSS_SELECTOR,
-                            timeout=settings.LARGE_TIMEOUT):
+def wait_for_attribute(
+    driver,
+    selector,
+    attribute,
+    value=None,
+    by=By.CSS_SELECTOR,
+    timeout=settings.LARGE_TIMEOUT,
+):
+    """
+    Searches for the specified element attribute by the given selector.
+    Returns the element object if the expected attribute is present
+    and the expected attribute value is present (if specified).
+    Raises NoSuchElementException if the element does not exist in the HTML
+    within the specified timeout.
+    Raises NoSuchAttributeException if the element exists in the HTML,
+    but the expected attribute/value is not present within the timeout.
+    @Params
+    driver - the webdriver object (required)
+    selector - the locator for identifying the page element (required)
+    attribute - the attribute that is expected for the element (required)
+    value - the attribute value that is expected (Default: None)
+    by - the type of selector being used (Default: By.CSS_SELECTOR)
+    timeout - the time to wait for elements in seconds
+    @Returns
+    A web element object that contains the expected attribute/value
+    """
+    element = None
+    element_present = False
+    attribute_present = False
+    found_value = None
+    start_ms = time.time() * 1000.0
+    stop_ms = start_ms + (timeout * 1000.0)
+    for x in range(int(timeout * 10)):
+        s_utils.check_if_time_limit_exceeded()
+        try:
+            element = driver.find_element(by=by, value=selector)
+            element_present = True
+            attribute_present = False
+            found_value = element.get_attribute(attribute)
+            if found_value is not None:
+                attribute_present = True
+            else:
+                element = None
+                raise Exception()
+
+            if value is not None:
+                if found_value == value:
+                    return element
+                else:
+                    element = None
+                    raise Exception()
+            else:
+                return element
+        except Exception:
+            now_ms = time.time() * 1000.0
+            if now_ms >= stop_ms:
+                break
+            time.sleep(0.1)
+    plural = "s"
+    if timeout == 1:
+        plural = ""
+    if not element:
+        if not element_present:
+            # The element does not exist in the HTML
+            message = "Element {%s} was not present after %s second%s!" % (
+                selector,
+                timeout,
+                plural,
+            )
+            timeout_exception(NoSuchElementException, message)
+        if not attribute_present:
+            # The element does not have the attribute
+            message = (
+                "Expected attribute {%s} of element {%s} was not present "
+                "after %s second%s!" % (attribute, selector, timeout, plural)
+            )
+            timeout_exception(NoSuchAttributeException, message)
+        # The element attribute exists, but the expected value does not match
+        message = (
+            "Expected value {%s} for attribute {%s} of element {%s} was not "
+            "present after %s second%s! (The actual value was {%s})"
+            % (value, attribute, selector, timeout, plural, found_value)
+        )
+        timeout_exception(NoSuchAttributeException, message)
+
+
+def wait_for_element_absent(
+    driver, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector.
     Raises an exception if the element is still present after the
@@ -446,14 +585,17 @@ def wait_for_element_absent(driver, selector, by=By.CSS_SELECTOR,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Element {%s} was still present after %s second%s!"
-        "" % (selector, timeout, plural))
+    message = "Element {%s} was still present after %s second%s!" % (
+        selector,
+        timeout,
+        plural,
+    )
     timeout_exception(Exception, message)
 
 
-def wait_for_element_not_visible(driver, selector, by=By.CSS_SELECTOR,
-                                 timeout=settings.LARGE_TIMEOUT):
+def wait_for_element_not_visible(
+    driver, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the specified element by the given selector.
     Raises an exception if the element is still visible after the
@@ -482,14 +624,17 @@ def wait_for_element_not_visible(driver, selector, by=By.CSS_SELECTOR,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Element {%s} was still visible after %s second%s!"
-        "" % (selector, timeout, plural))
+    message = "Element {%s} was still visible after %s second%s!" % (
+        selector,
+        timeout,
+        plural,
+    )
     timeout_exception(Exception, message)
 
 
-def wait_for_text_not_visible(driver, text, selector, by=By.CSS_SELECTOR,
-                              timeout=settings.LARGE_TIMEOUT):
+def wait_for_text_not_visible(
+    driver, text, selector, by=By.CSS_SELECTOR, timeout=settings.LARGE_TIMEOUT
+):
     """
     Searches for the text in the element of the given selector on the page.
     Returns True if the text is not visible on the page within the timeout.
@@ -516,9 +661,12 @@ def wait_for_text_not_visible(driver, text, selector, by=By.CSS_SELECTOR,
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Text {%s} in {%s} was still visible after %s "
-        "second%s!" % (text, selector, timeout, plural))
+    message = "Text {%s} in {%s} was still visible after %s second%s!" % (
+        text,
+        selector,
+        timeout,
+        plural,
+    )
     timeout_exception(Exception, message)
 
 
@@ -535,7 +683,7 @@ def find_visible_elements(driver, selector, by=By.CSS_SELECTOR):
     try:
         v_elems = [element for element in elements if element.is_displayed()]
         return v_elems
-    except (StaleElementReferenceException, ENI_Exception):
+    except (StaleElementReferenceException, ElementNotInteractableException):
         time.sleep(0.1)
         elements = driver.find_elements(by=by, value=selector)
         v_elems = []
@@ -554,7 +702,7 @@ def save_screenshot(driver, name, folder=None):
     if not name.endswith(".png"):
         name = name + ".png"
     if folder:
-        abs_path = os.path.abspath('.')
+        abs_path = os.path.abspath(".")
         file_path = abs_path + "/%s" % folder
         if not os.path.exists(file_path):
             os.makedirs(file_path)
@@ -581,10 +729,12 @@ def save_page_source(driver, name, folder=None):
     name - The file name to save the current page's HTML to.
     folder - The folder to save the file to. (Default = current folder)
     """
+    from seleniumbase.core import log_helper
+
     if not name.endswith(".html"):
         name = name + ".html"
     if folder:
-        abs_path = os.path.abspath('.')
+        abs_path = os.path.abspath(".")
         file_path = abs_path + "/%s" % folder
         if not os.path.exists(file_path):
             os.makedirs(file_path)
@@ -594,7 +744,8 @@ def save_page_source(driver, name, folder=None):
     page_source = driver.page_source
     html_file = codecs.open(html_file_path, "w+", "utf-8")
     rendered_source = log_helper.get_html_source_with_base_href(
-        driver, page_source)
+        driver, page_source
+    )
     html_file.write(rendered_source)
     html_file.close()
 
@@ -603,9 +754,9 @@ def _get_last_page(driver):
     try:
         last_page = driver.current_url
     except Exception:
-        last_page = '[WARNING! Browser Not Open!]'
+        last_page = "[WARNING! Browser Not Open!]"
     if len(last_page) < 5:
-        last_page = '[WARNING! Browser Not Open!]'
+        last_page = "[WARNING! Browser Not Open!]"
     return last_page
 
 
@@ -615,8 +766,9 @@ def save_test_failure_data(driver, name, browser_type, folder=None):
     If the folder provided doesn't exist, it will get created.
     """
     import traceback
+
     if folder:
-        abs_path = os.path.abspath('.')
+        abs_path = os.path.abspath(".")
         file_path = abs_path + "/%s" % folder
         if not os.path.exists(file_path):
             os.makedirs(file_path)
@@ -628,10 +780,14 @@ def save_test_failure_data(driver, name, browser_type, folder=None):
     data_to_save = []
     data_to_save.append("Last_Page: %s" % last_page)
     data_to_save.append("Browser: %s " % browser_type)
-    data_to_save.append("Traceback: " + ''.join(
-        traceback.format_exception(sys.exc_info()[0],
-                                   sys.exc_info()[1],
-                                   sys.exc_info()[2])))
+    data_to_save.append(
+        "Traceback: "
+        + "".join(
+            traceback.format_exception(
+                sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2]
+            )
+        )
+    )
     failure_data_file.writelines("\r\n".join(data_to_save))
     failure_data_file.close()
 
@@ -685,8 +841,7 @@ def wait_for_and_switch_to_alert(driver, timeout=settings.LARGE_TIMEOUT):
             if now_ms >= stop_ms:
                 break
             time.sleep(0.1)
-    message = (
-        "Alert was not present after %s seconds!" % timeout)
+    message = "Alert was not present after %s seconds!" % timeout
     timeout_exception(Exception, message)
 
 
@@ -699,6 +854,8 @@ def switch_to_frame(driver, frame, timeout=settings.SMALL_TIMEOUT):
     frame - the frame element, name, id, index, or selector
     timeout - the time to wait for the alert in seconds
     """
+    from seleniumbase.fixtures import page_utils
+
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
@@ -727,9 +884,11 @@ def switch_to_frame(driver, frame, timeout=settings.SMALL_TIMEOUT):
     plural = "s"
     if timeout == 1:
         plural = ""
-    message = (
-        "Frame {%s} was not visible after %s second%s!"
-        "" % (frame, timeout, plural))
+    message = "Frame {%s} was not visible after %s second%s!" % (
+        frame,
+        timeout,
+        plural,
+    )
     timeout_exception(Exception, message)
 
 
@@ -759,9 +918,11 @@ def switch_to_window(driver, window, timeout=settings.SMALL_TIMEOUT):
         plural = "s"
         if timeout == 1:
             plural = ""
-        message = (
-            "Window {%s} was not present after %s second%s!"
-            "" % (window, timeout, plural))
+        message = "Window {%s} was not present after %s second%s!" % (
+            window,
+            timeout,
+            plural,
+        )
         timeout_exception(Exception, message)
     else:
         window_handle = window
@@ -778,7 +939,9 @@ def switch_to_window(driver, window, timeout=settings.SMALL_TIMEOUT):
         plural = "s"
         if timeout == 1:
             plural = ""
-        message = (
-            "Window {%s} was not present after %s second%s!"
-            "" % (window, timeout, plural))
+        message = "Window {%s} was not present after %s second%s!" % (
+            window,
+            timeout,
+            plural,
+        )
         timeout_exception(Exception, message)
