@@ -1,5 +1,5 @@
 """
-The S3 Logging Plugin to upload all logs to the S3 bucket specifed.
+The S3 Logging Plugin to upload all logs to the S3 bucket specified.
 """
 
 import uuid
@@ -13,7 +13,8 @@ class S3Logging(Plugin):
     """
     The plugin for uploading test logs to the S3 bucket specified.
     """
-    name = 's3_logging'  # Usage: --with-s3_logging
+
+    name = "s3_logging"  # Usage: --with-s3_logging
 
     def configure(self, options, conf):
         """ Get the options. """
@@ -24,15 +25,15 @@ class S3Logging(Plugin):
         """ After each testcase, upload logs to the S3 bucket. """
         s3_bucket = S3LoggingBucket()
         guid = str(uuid.uuid4().hex)
-        path = "%s/%s" % (self.options.log_path,
-                          test.test.id())
+        path = "%s/%s" % (self.options.log_path, test.test.id())
         uploaded_files = []
         for logfile in os.listdir(path):
-            logfile_name = "%s/%s/%s" % (guid,
-                                         test.test.id(),
-                                         logfile.split(path)[-1])
-            s3_bucket.upload_file(logfile_name,
-                                  "%s/%s" % (path, logfile))
+            logfile_name = "%s/%s/%s" % (
+                guid,
+                test.test.id(),
+                logfile.split(path)[-1],
+            )
+            s3_bucket.upload_file(logfile_name, "%s/%s" % (path, logfile))
             uploaded_files.append(logfile_name)
         s3_bucket.save_uploaded_file_names(uploaded_files)
         index_file = s3_bucket.upload_index_file(test.id(), guid)
@@ -42,8 +43,11 @@ class S3Logging(Plugin):
         # If the database plugin is running, attach a link
         # to the logs index database row
         if hasattr(test.test, "testcase_guid"):
-            from seleniumbase.core.testcase_manager \
-                import TestcaseDataPayload, TestcaseManager
+            from seleniumbase.core.testcase_manager import (
+                TestcaseDataPayload,
+                TestcaseManager,
+            )
+
             self.testcase_manager = TestcaseManager(self.options.database_env)
             data_payload = TestcaseDataPayload()
             data_payload.guid = test.test.testcase_guid
